@@ -2,7 +2,7 @@ package DBIx::QuickDB::Util;
 use strict;
 use warnings;
 
-our $VERSION = '0.000011';
+our $VERSION = '0.000012';
 
 use IPC::Cmd qw/can_run/;
 use Carp qw/confess/;
@@ -22,8 +22,7 @@ BEGIN {
 sub clone_dir {
     return _clone_dir_rsync(@_) if $RSYNC;
     return _clone_dir_cp(@_)    if $CP;
-
-    confess "Could not find a method of cloning a directory.";
+    return _clone_dir_fcr(@_);
 }
 
 sub _clone_dir_rsync {
@@ -36,6 +35,13 @@ sub _clone_dir_cp {
     system($CP, '-a', $params{verbose} ? ( '-v' ) : (), "$src/", $dest) and die "$CP returned $?";
 }
 
+sub _clone_dir_fcr {
+    my ($src, $dest, %params) = @_;
+    require File::Copy::Recursive;
+
+    File::Copy::Recursive::dircopy($src, $dest) or die "$!";
+}
+
 sub strip_hash_defaults {
     my ($hash, $defaults) = @_;
 
